==> quarkus-datasource-deployment-spi-2.9.1.Final-sources.jar: io/quarkus/datasource/deployment/spi/DevServicesDatasourceProvider.java <==
package io.quarkus.datasource.deployment.spi;

import java.io.Closeable;
import java.time.Duration;
import java.util.Map;
import java.util.Optional;
import java.util.OptionalInt;

import io.quarkus.runtime.LaunchMode;

public interface DevServicesDatasourceProvider {

    RunningDevServicesDatasource startDatabase(Optional<String> username, Optional<String> password,
            Optional<String> datasourceName,
            Optional<String> imageName,
            Map<String, String> containerProperties,
            Map<String, String> additionalJdbcUrlProperties,
            OptionalInt port, LaunchMode launchMode, Optional<Duration> startupTimeout);

    default boolean isDockerRequired() {
        return true;
    }

    class RunningDevServicesDatasource {

        private final String id;
        private final String url;
        private final String username;
        private final String password;
        private final Closeable closeTask;

        public RunningDevServicesDatasource(String id, String url, String username, String password, Closeable closeTask) {
            this.id = id;
            this.url = url;
            this.username = username;
            this.password = password;
            this.closeTask = closeTask;
        }

        public String getId() {
            return id;
        }

        public String getUrl() {
            return url;
        }

        public Closeable getCloseTask() {
            return closeTask;
        }

        public String getUsername() {
            return username;
        }

        public String getPassword() {
            return password;
        }

    }

}

==> quarkus-datasource-deployment-spi-2.9.2.Final-sources.jar: io/quarkus/datasource/deployment/spi/DevServicesDatasourceProvider.java <==
package io.quarkus.datasource.deployment.spi;

import java.io.Closeable;
import java.time.Duration;
import java.util.Map;
import java.util.Optional;
import java.util.OptionalInt;

import io.quarkus.runtime.LaunchMode;

public interface DevServicesDatasourceProvider {

    RunningDevServicesDatasource startDatabase(Optional<String> username, Optional<String> password,
            Optional<String> datasourceName,
            Optional<String> imageName,
            Map<String, String> containerProperties,
            Map<String, String> additionalJdbcUrlProperties,
            OptionalInt port, LaunchMode launchMode, Optional<Duration> startupTimeout);

    default boolean isDockerRequired() {
        return true;
    }

    class RunningDevServicesDatasource {

        private final String id;
        private final String jdbcUrl;
        private final String reactiveUrl;
        private final String username;
        private final String password;
        private final Closeable closeTask;

        public RunningDevServicesDatasource(String id, String jdbcUrl, String reactiveUrl, String username, String password,
                Closeable closeTask) {
            this.id = id;
            this.jdbcUrl = jdbcUrl;
            this.reactiveUrl = reactiveUrl;
            this.username = username;
            this.password = password;
            this.closeTask = closeTask;
        }

        public String getId() {
            return id;
        }

        public String getJdbcUrl() {
            return jdbcUrl;
        }

        public String getReactiveUrl() {
            return reactiveUrl;
        }

        public Closeable getCloseTask() {
            return closeTask;
        }

        public String getUsername() {
            return username;
        }

        public String getPassword() {
            return password;
        }

    }

}
